@@ -14,28 +14,9 @@ sanity_align <- function(align, i) {
   }
 }
 
-sanitize_i <- function(i, x, pre_group_i = FALSE, lazy = TRUE) {
-  out <- seq_len(nrow(x))
-  if (is.null(i) && isTRUE(lazy)) {
-    out <- NA
-    attr(out, "null") <- TRUE
-    attr(out, "body") <- seq_len(nrow(x))
-    attr(out, "head") <- integer()
-  } else {
-    if (!is.null(i)) {
-      out <- i
-    } else if (inherits(x, "tinytable")) {
-      out <- seq_len(nrow(x@table_dataframe))
-    }
-    attr(out, "null") <- FALSE
-    attr(out, "body") <- out[out > 0]
-    attr(out, "head") <- out[out < 1]
-  }
-  return(out)
-}
 sanitize_i <- function(i, x, pre_group_i = FALSE, lazy = TRUE) {
   if (is.character(i)) {
-    assert_choice(i, c("notes", "caption"))
+    assert_choice(i, c("notes", "caption", "groupi"))
     return(i)
   } else if (is.matrix(i) && is.logical(i)) {
     return(i)
